==> igloo_0_1_8.zip: igloo_0_1_8/igloo/language/1/barnraiser_01/register.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//SECTIONS
$lang['hdr_invite'] = 							"you've been invited";
$lang['hdr_registration'] = 					"registration form";
$lang['hdr_instructions'] =						"instructions";
$lang['hdr_reg_complete'] = 					"your registration is complete";
$lang['hdr_preview'] =							"preview";


//SUBMIT BUTTONS
$lang['sub_register'] = 						"register";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_preview'] = 							"preview";


//EMAIL MESSAGE SUBJECTS
$lang['subject_welcome_br'] = 					"Welcome to Igloo";


//TEXTS
$lang['txt_dob'] = 								"Date of birth";
$lang['txt_email'] = 							"Email";
$lang['txt_firstname'] = 						"Firstname";
$lang['txt_lang'] = 							"Preferred language";
$lang['txt_instructions'] =						"Fill out the registration form. Once you've finished press the 'register' button and you will get an email from us with your access information.<br /><p><b>Firstname</b><br />We only use this to send you a personal email. You can change it when you setup your account.<br /><p><b>Place of residence</b><br />Your place of residence is the city, town or village you live now.<br /></p><p><b>Your privacy</b><br />We record your gender, date of birth and place of residence for summary statistics for the community only. This information is not revealed to any member of the community.</p><p><b>Date of birth</b><br />Remember to put your correct date of birth. If you ever forget your password we will ask you for this before we give you a new one.<br /></p><p><b>Captcha</b><br />'captcha' (Completely Automated Public Turing to tell Computers from Humans Apart) is a system to provide practical security for you as humans can read distorted text but current computer programs can't. If you are visually impaired or cannot otherwise read the captcha word please contact the 'administration' for help. You can find contact details in our '<a href=\"node_structure.php\">rules &amp; information'</a> section.</p>";
$lang['txt_invited_personal'] =					"Join my network!";
$lang['txt_reg_legal'] = 						"I agree to observe the laws of my country within this site and the rules stipulated in our '<a href=\"node_structure.php\">rules &amp; information'</a> section. For countries that are not open or do not support human rights and democracy, I agree that this site has the right to impose site rules as defined by Swedish law.";
$lang['txt_welcome'] = 							"Simply fill in the form to register and you will receive an email with access information.";
$lang['txt_index_intro_post_reg'] = 			"Thank you for completing registration with us.";
$lang['txt_instructions2'] =					"Check your email! You will receive an email from us with a link in it. Press the link to complete registration.<br />";
$lang['txt_lang_selection'] = 					"languages I can read";
$lang['txt_preview'] = 							"check your information and if correct press 'register'";
$lang['txt_default_profile_name'] = 			"default";
$lang['txt_default_profile_hometown'] = 		"Stockholm";
$lang['txt_captcha'] = 							"Captcha";
$lang['txt_captcha_intro'] = 					"Please type the characters that you see below.";
$lang['txt_captcha_hint'] = 					"If you are visually impaired or cannot otherwise read the captcha word please contact the 'administration' for help. You can find contact details in our '<a href=\"node_structure.php\">rules &amp; information'</a> section.";

?>

==> igloo_0_1_9.zip: igloo_0_1_9/igloo/language/1/barnraiser_01/register.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//SECTIONS
$lang['hdr_invite'] = 							"you've been invited";
$lang['hdr_registration'] = 					"registration form";
$lang['hdr_instructions'] =						"instructions";
$lang['hdr_reg_complete'] = 					"your registration is complete";
$lang['hdr_preview'] =							"preview";


//SUBMIT BUTTONS
$lang['sub_register'] = 						"register";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_preview'] = 							"preview";


//EMAIL MESSAGE SUBJECTS
$lang['subject_welcome_br'] = 					"Welcome to Igloo";


//TEXTS
$lang['txt_email'] = 							"Email";
$lang['txt_firstname'] = 						"Firstname";
$lang['txt_lang'] = 							"Preferred language";
$lang['txt_instructions'] =						"<p>Just follow our simple regitration process to come on in!</p><p><b>step 1 - registration</b><br />Fill out the registration and press 'register'.<br /></p><p><b>step 2 - verification</b><br />Check your email. You will recieve an email from us with a link and an access code.<br />Click the link to open a setup page.<br /></p><p><b>step 3 - setup</b><br />Fill in the setup and add your access code. Press 'go' and you are in!<br /></p>";
$lang['txt_invited_personal'] =					"Join my network!";
$lang['txt_reg_legal'] = 						"I agree to observe the laws of my country within this site and the rules stipulated in our '<a href=\"node_structure.php\">rules &amp; information'</a> section. For countries that are not open or do not support human rights and democracy, I agree that this site has the right to impose site rules as defined by Swedish law.";
$lang['txt_welcome'] = 							"<b>Simply fill in the form to register and you will receive an email with an access code and a link to our setup page.</b>";
$lang['txt_index_intro_post_reg'] = 			"Thank you for completing registration with us.";
$lang['txt_instructions2'] =					"Check your email! You will receive an email from us with a link in it. Press the link to complete registration.<br />";
$lang['txt_lang_selection'] = 					"languages I can read";
$lang['txt_preview'] = 							"check your information and if correct press 'register'";
$lang['txt_default_profile_name'] = 			"default";
$lang['txt_default_profile_hometown'] = 		"Stockholm";
$lang['txt_captcha'] = 							"Captcha";
$lang['txt_captcha_intro'] = 					"Please type the characters that you see below.";
$lang['txt_captcha_hint'] = 					"If you are visually impaired or cannot otherwise read the captcha word please contact the 'administration' for help. You can find contact details in our '<a href=\"node_structure.php\">rules &amp; information'</a> section.";

?>
